Range Object
============

Analogous to its counterpart in Excel, the xlwings Range object represents a selection of cells containing one or more
contiguous blocks of cells in Excel.

.. module:: xlwings


.. autoclass:: Range
    :members:


